@@ -1254,6 +1254,17 @@ class Pon:
         else:
             self.pb.ClearField('name')
 
+    @property
+    def description(self):
+        return self.pb.description if self.pb.HasField('description') else None
+
+    @description.setter
+    def description(self, value):
+        if value is not None:
+            self.pb.description = value
+        else:
+            self.pb.ClearField('description')
+
 
 class Interface:
 
